import { ThemeConfig, extendTheme, Button } from '@chakra-ui/react'

import { tableTheme } from './table-theme'

const config: ThemeConfig = {
  initialColorMode: 'light',
  useSystemColorMode: false,
  cssVarPrefix: 'pg',
}

export const theme = extendTheme({
  config,
  colors: {
    transparent: 'transparent',
    currentColor: 'currentColor',
    current: 'currentColor',
  },
  components: {
    Table: tableTheme,
    Button,
  },
  radii: {
    none: '0',
    xs: '2px',
    sm: '0.2rem',
    base: '0.4rem',
    md: '0.6rem',
    lg: '0.8rem',
    xl: '1.2rem',
    '2xl': '1.6rem',
    '3xl': '2.4rem',
    full: '9999px',
  },
  fonts: {
    body: `Inter,"Segoe UI","Roboto","Oxygen","Ubuntu","Cantarell","Fira Sans","Droid Sans","Helvetica Neue", system-ui, sans-serif`,
    heading: `Inter,"Segoe UI","Roboto","Oxygen","Ubuntu","Cantarell","Fira Sans","Droid Sans","Helvetica Neue", system-ui, sans-serif`,
    mono: `Menlo, Monaco, Consolas, 'Courier New', monospace`,
  },
  fontSizes: {
    '4': '16px',
    '5': '20px',
    '6': '24px',
    '7': '28px',
    '8': '32px',
    '9': '36px',
    '10': '48px',
    xs: '12px',
    sm: '14px',
    md: '16px',
    lg: '20px',
    xl: '28px',
    '2xl': '36px',
    '3xl': '48px',
  },
  fontWeights: {
    light: 300,
    normal: 400,
    medium: 500,
    bold: 700,
  },
  lineHeights: {
    normal: 'normal',
    none: '1',
    shorter: '1.25',
    short: '1.375',
    base: '1.5',
    tall: '1.625',
    taller: '2',
  },
  letterSpacings: {
    tighter: '-0.05em',
    tight: '-0.025em',
    normal: '0',
    wide: '0.025em',
    wider: '0.0625em',
    widest: '0.1em',
  },
  textStyles: {
    '-2': {
      fontSize: 'xs',
      lineHeight: 'short',
    },
    '-2u': {
      letterSpacing: 'wider',
      fontSize: 'xs',
      fontWeight: 'bold',
      lineHeight: 'short',
      textTransform: 'uppercase',
    },
    '-1': {
      fontSize: 'sm',
      lineHeight: 'short',
    },
    '-1u': {
      letterSpacing: 'wider',
      fontSize: 'sm',
      lineHeight: 'short',
      fontWeight: 'bold',
      textTransform: 'uppercase',
    },
    '1': {
      fontSize: 'md',
      lineHeight: 'base',
    },
    '2': {
      fontSize: 'lg',
      lineHeight: 'shorter',
    },
    '3': {
      fontSize: 'xl',
      lineHeight: '1.142857143',
    },
    '4': {
      fontSize: '2xl',
      lineHeight: 'short',
    },
    '5': {
      fontSize: '3xl',
      lineHeight: 'tall',
    },
    inherit: {
      fontSize: 'inherit',
      lineHeight: 'inherit',
      color: 'inherit',
      bgColor: 'inherit',
    },
  },
})
